import {FC, useCallback, useEffect, useState} from "react";
import {Image, View} from "@tarojs/components";
import {brandApi, BrandRecord} from "@/api";
import styles from './list.module.scss'
import Taro, {useReachBottom} from "@tarojs/taro";
import Empty from "@/components/empty/empty";

const BrandList: FC = () => {
  const [page, setPage] = useState(1)
  const [brands, setBrands] = useState<BrandRecord[]>([])
  const [total, setTotal] = useState(0)

  useEffect(() => {
    getData()
  }, [page])

  const getData = useCallback(async () => {
    try {
      const res = await brandApi.list(1, 10)
      setTotal(res.total)
      setBrands([
        ...res.data
      ])
    } catch (e) {
    }
  }, [page])


  function jumpInfo(id: number) {
    Taro.navigateTo({url: `/pages/preview/brand/info/info?id=${id}`})
  }

  useReachBottom(useCallback(() => {
    if (brands?.length < total) {
      setPage(page + 1)
    }
  }, [total, brands]))


  return (
    <View className='p-2'>
      {
        brands.length ? brands.map((d) =>
            <View onClick={() => jumpInfo(d.id)} className={styles.box} key={d.id}>
              <Image src={d.brand_album?.[0]} mode='aspectFill' className={styles.image}/>
              <View className={styles.rightBox}>
                <View className='font-weight mb-2 font-28'>{d.name}</View>
                <View className={styles.desc}>{d.graphic_introduction.repeat(30)}</View>
              </View>
            </View>)
          : <Empty name='空空如也'/>
      }
    </View>
  )
}

export default BrandList
